@@ -19,7 +19,7 @@
 LPM.VaR <- function(percentile, degree, x){
 
     sort_x <- sort(x)
-    index <- findInterval(1 - percentile, LPM.ratio(0, sort_x, x))
+    index <- findInterval(1 - percentile, LPM.ratio(degree, sort_x, x))
     return(mean(sort_x[index:(index + 1)]))
 
 }
@@ -42,7 +42,7 @@ LPM.VaR <- function(percentile, degree, x){
 UPM.VaR <- function(percentile, degree, x){
 
     sort_x <- sort(x,decreasing = TRUE)
-    index <- findInterval(1 - percentile, UPM.ratio(0, sort_x, x))
+    index <- findInterval(1 - percentile, UPM.ratio(degree, sort_x, x))
     return(mean(sort_x[(index - 1):index]))
 
 }
