@@ -23,8 +23,11 @@
 #'  \item{\code{"ensemble"}} Returns the ensemble of both \code{"univariate"} and \code{"multivariate"} forecasts.
 #'  }
 #'
-#' @note \code{dim.red.method = "cor"} is significantly faster than the other methods, but comes at the expense of ignoring possible nonlinear relationships between lagged variables.
-#'
+#' @note
+#' \itemize{
+#' \item \code{dim.red.method = "cor"} is significantly faster than the other methods, but comes at the expense of ignoring possible nonlinear relationships between lagged variables.
+#' \item Not recommended for factor variables, even after transformed to numeric.  \link{NNS.reg} is better suited for factor or binary regressor extrapolation.
+#' }
 #'
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
@@ -77,6 +80,14 @@ NNS.VAR <- function(variables,
 
   nns_IVs <- list()
 
+  if(is.null(colnames(variables))){
+    var_names <- character()
+    for(i in 1:ncol(variables)){
+        var_names[i] <- paste0("x",i)
+    }
+    colnames(variables) <- var_names
+  }
+
   # Parallel process...
   if (is.null(ncores)) {
     cores <- detectCores()
@@ -133,7 +144,7 @@ NNS.VAR <- function(variables,
 
 
   new_values <- data.frame(do.call(cbind, new_values))
-  colnames(new_values) <- colnames(variables)
+  colnames(new_values) <- as.character(colnames(variables))
 
   # Now lag new forecasted data.frame
   lagged_new_values <- lag.mtx(new_values, tau = tau)
@@ -244,7 +255,7 @@ NNS.VAR <- function(variables,
   RV <- lapply(relevant_vars, function(x) if(is.null(x)){NA} else {x})
 
   RV <- do.call(cbind, lapply(RV, `length<-`, max(lengths(RV))))
-  colnames(RV) <- colnames(variables)
+  colnames(RV) <- as.character(colnames(variables))
 
   uni <- numeric()
   multi <- numeric()
